@@ -177,6 +177,28 @@ def in_map(x, v):
         return False
 
 
+def array_equal(a,b):
+    """
+    Recursively determine if two values or arrays are equal.
+
+    NumPy ops (e.g. array_equal) are not sufficiently general purpose for this, so we need our own.
+    """
+    if is_list(a):
+        if is_list(b):
+            if len(a) != len(b):
+                return False
+        else:
+            return False
+    else:
+        if is_list(b):
+            return False
+        else:
+            return np.isclose(a,b) if is_number(a) and is_number(b) else a == b
+
+    r = np.asarray([array_equal(x,y) for x,y in zip(a,b)])
+    return r.all()
+
+
 def has_none(a):
     if safe_eq(a, None) or not isinstance(a,list):
         return False
